import './Checkers.css'
import React from 'react'

export const Color = {
    white: "WHITE",
    black: "BLACK",

    opposite: (color) => {
        if (color === Color.white)
            return Color.black;
        if (color === Color.black)
            return Color.white;

        return color;
    }
};

/*
 * Stone
 */
export function Stone({ color }) {
    switch (color) {
        case Color.white:
            return WhiteStone();

        case Color.black:
            return BlackStone();

        default:
            console.warn("Unknown color: ", color)
    }
}

export function WhiteStone() {
    return <span className="Stone white">⛀</span>
}

export function BlackStone() {
    return <span className="Stone black">⛂</span>
}

/*
 * Player
 */
export function Player({ color, name }) {
    return (
        <div className='Player'>
            <Stone color={color} />
            {name}
        </div>
    )
}

/*
 * Board
 */
export function Board() {

    return <div className='Board'>
        <div className='row'>
            <BlackTile /> <WhiteTile id={0} stone={WhiteStone()} />
            <BlackTile /> <WhiteTile id={1} stone={WhiteStone()} />
            <BlackTile /> <WhiteTile id={2} stone={WhiteStone()} />
            <BlackTile /> <WhiteTile id={4} stone={WhiteStone()} />
        </div>
        <div className='row'>
            <WhiteTile id={5} stone={WhiteStone()} /> <BlackTile />
            <WhiteTile id={6} stone={WhiteStone()} /> <BlackTile />
            <WhiteTile id={7} stone={WhiteStone()} /> <BlackTile />
            <WhiteTile id={8} stone={WhiteStone()} /> <BlackTile />
        </div>
        <div className='row'>
            <BlackTile /> <WhiteTile id={9} stone={WhiteStone()} />
            <BlackTile /> <WhiteTile id={10} stone={WhiteStone()} />
            <BlackTile /> <WhiteTile id={11} stone={WhiteStone()} />
            <BlackTile /> <WhiteTile id={12} stone={WhiteStone()} />
        </div>
        <div className='row'>
            <WhiteTile id={13} stone={null} /> <BlackTile />
            <WhiteTile id={14} stone={null} /> <BlackTile />
            <WhiteTile id={15} stone={null} /> <BlackTile />
            <WhiteTile id={16} stone={null} /> <BlackTile />
        </div>

        <div className='row'>
            <BlackTile /> <WhiteTile id={17} stone={null} />
            <BlackTile /> <WhiteTile id={18} stone={null} />
            <BlackTile /> <WhiteTile id={19} stone={null} />
            <BlackTile /> <WhiteTile id={20} stone={null} />
        </div>
        <div className='row'>
            <WhiteTile id={21} stone={BlackStone()} /> <BlackTile />
            <WhiteTile id={22} stone={BlackStone()} /> <BlackTile />
            <WhiteTile id={23} stone={BlackStone()} /> <BlackTile />
            <WhiteTile id={24} stone={BlackStone()} /> <BlackTile />
        </div>
        <div className='row'>
            <BlackTile /> <WhiteTile id={25} stone={BlackStone()} />
            <BlackTile /> <WhiteTile id={26} stone={BlackStone()} />
            <BlackTile /> <WhiteTile id={27} stone={BlackStone()} />
            <BlackTile /> <WhiteTile id={28} stone={BlackStone()} />
        </div>
        <div className='row'>
            <WhiteTile id={29} stone={BlackStone()} /> <BlackTile />
            <WhiteTile id={30} stone={BlackStone()} /> <BlackTile />
            <WhiteTile id={31} stone={BlackStone()} /> <BlackTile />
            <WhiteTile id={32} stone={BlackStone()} /> <BlackTile />
        </div>
    </div>
}

function WhiteTile({ id, stone }) {
    return (
        <div className='Tile white'
            onClick={() => console.log('click', id)}
        >
            {stone}
        </div>
    );
}

function BlackTile() {
    return <div className='Tile black' />
}