import React, { useContext } from 'react';
import Wobler from '../../../components/Wobler';
import { GamesContext } from '../../../context/games';

export function DrawRequest({ onClick }) {
    const games = useContext(GamesContext);

    const selectedGame = games.findGame({ uuid: games.active.selectedUUID });
    const gameStatus = selectedGame?.status;
    const isReady = gameStatus === 'GAME_BOARD_WAIT_FOR_YOU' ? true : '';

    const checkStatus = () => {
        if (!selectedGame)
            return alert('You have to select a game');

        if (gameStatus === 'DRAW_REQUEST_WAIT_FOR_OPPONENT')
            return alert('A draw was alredy offered to the opponent');

        if (!isReady)
            return alert('You can ask for a draw only during your turn');

        onClick(selectedGame.uuid);
    }

    if (gameStatus === 'DRAW_REQUEST_WAIT_FOR_YOU')
        return; // You can not send counter draw request

    return (
        <button className={'Draw' + (isReady && ' ready')} onClick={() => checkStatus()} >
            <Wobler text="Draw?" dance={games.isPushingGameDrawRequest} />
        </button >
    )
}

export function DrawAccept({ onClick }) {
    const games = useContext(GamesContext);

    const selectedGame = games.findGame({ uuid: games.active.selectedUUID });
    const gameStatus = selectedGame?.status;

    if (gameStatus === 'DRAW_REQUEST_WAIT_FOR_YOU')
        return (
            <button className='Draw accept' onClick={() => onClick(selectedGame.uuid)} >
                <Wobler text="Draw accept" dance={games.isPushingGameDrawAccept} />
            </button>
        )
}

export function DrawReject({ onClick }) {
    const games = useContext(GamesContext);

    const selectedGame = games.findGame({ uuid: games.active.selectedUUID });

    if (selectedGame?.status === 'DRAW_REQUEST_WAIT_FOR_YOU')
        return (
            <button className='Draw reject' onClick={() => onClick(selectedGame.uuid)} >
                <Wobler text="Reject" dance={games.isPushingGameDrawReject} />
            </button>
        )
}